<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>MystiQ について</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>インフォメーション</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>翻訳者</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>ポータブル</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Qt %1 によってコンパイル</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>libnotify %1 でコンパイル</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>MystiQ 公式サイト: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>一部のオーディオ処理機能は SoX によって提供されています.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>スペイン語 (Spanien)</translation>
    </message>
    <message>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ は FFmpeg の GUI フロントエンドツールです.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>開発者一覧:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation>スウェーデン語（スウェーデン）</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation>日本語（日本）</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation>ドイツ語 (Germany)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation>イタリア語（イタリア）</translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>アプリケーション名：&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>このプログラムはフリーソフトウェアです。 GNU General Public Licenseバージョン3の条件の下で、再配布および/または変更することができます。</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation>トルコ語（トルコ）</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>多くの人々が翻訳に貢献してきました。 MystiQ Video Converterを自分の言語に翻訳することもできます。訪問 </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> 翻訳チームに参加します。</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation>ハンガリー語（ハンガリー）</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation>ロシア語（ロシア）</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>共同編集者：&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>MystiQ Video Converterのいくつかの機能は、</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translatorcomment>ガリシア語（ガリシア）</translatorcomment>
        <translation>ガリシア語（ガリシア）</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>アイコンのテーマ：&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>FFmpeg について</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>利用可能なコーデック</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpeg ist eine vollständige plattformübergreifende Lösung zum Aufzeichnen, Konvertieren und Streamen von Audio und Video. Es enthält libavcodec - die führende Audio / Video-Codec-Bibliothek.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg ist freie Software, die unter der LGPL oder GPL lizenziert ist.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>詳細な情報は %1 でご確認ください。</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>タスクを追加</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>変換するファイル</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>追加ファイル。</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>選択したファイルを削除します。</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>出力設定</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>出力ビットレートを自動調整して、出力ファイルサイズを小さくする</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>音声ビットレートを自動調整</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>プリセット</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>変換先</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>出力パス</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>フォルダを選択(&amp;F)</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>参照</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translation>ソースフォルダ内に新規フォルダを作成(&amp;N)</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>フォルダ名</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translation>ソースと同じ場所に出力(&amp;S)</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>少なくともひとつのファイルを選択してください。</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>ファイルの選択</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>マルチメディア</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>映像</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音声</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>すべてのファイル</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>ファイルの検索...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>いくつかのファイルが見つかりませんでした。</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>フォルダが存在しません、新たなフォルダを作成しますか?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>フォルダを作成できませんでした、別の出力先フォルダを選択してください。</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>ファイルを追加</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>選択項目を除去</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>一覧をクリア</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>変換パラメータ</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音声</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>音声を無効化</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>音声設定</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>ビットレート</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(自動)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>KB/秒</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>チャンネル</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>映像</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>映像を無効化</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>映像設定</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>ソースと同じ量子化</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>インターレース解除</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>クロップ</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>時間</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>カッティング</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation>切る</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>プレビュー(&amp;P)</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>スケーリング</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速度</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>拡張</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>追加の FFmpeg オプション</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>音声をコピー (エンコードなし)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>利用可能な場合、字幕を追加</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>映像をコピー (最エンコードなし)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation>qrc:/qml/main.qml</translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>ビデオの追加オプション</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>黒から白へのビデオ</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>垂直反転</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>水平反転</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>時計回りに90度回転</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>反時計回りに90度回転</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>180度回転</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>ファイルを追加 (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>いくつかのファイルがコンバータで認識できません.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>新規ファイル名</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>新たに出力するファイルの名前を入力してください.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>出力ディレクトリ</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>FFmpeg からのエラーメッセージ:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>ここにファイルをドロップでタスクを追加.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>&quot;%1&quot; を隠す</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>すべての列を復元</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>ソース</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>対象</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>期間</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>ファイルサイズ</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>サンプルレート</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>音声ビットレート</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>チャンネル</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>音声コーデック</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>寸法</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>映像ビットレート</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>フレームレート</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>映像コーデック</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>進捗状況</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>タスクを除去しています...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>既にファイルが存在します</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 は既にディスク上、またはタスク一覧内に存在します。このまま出力ファイル名として使用しますか?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>タスクを除去</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>実行中のタスクは削除できません.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>完了</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>失敗しました</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>エラー: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>メディア ファイル形式間の変換</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>メディア コンバータ</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>ユーザ マニュアル</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>切断</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>先頭としてマーク</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>先頭までシーク</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>選択範囲の再生</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>末尾としてマーク</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>末尾までシーク</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>変換処理を開始</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>変換(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>ファイルを追加(&amp;A)</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>変換するファイルを追加</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>終了(&amp;X)</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>プログラムを終了</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>停止(&amp;T)</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>変換処理を停止</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>パラメータの設定(&amp;P)</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>パラメータの設定</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>選択したファイルの変換パラメータを編集</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt について</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Qt について</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>出力先フォルダを開く(&amp;O)</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>選択したファイルの出力先フォルダを開く</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>&amp;FFmpeg について</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>FFmpeg について</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>選択項目を除去(&amp;R)</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>選択したすべての項目をこの一覧から除去</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>完了済みを除去(&amp;E)</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>完了済みの項目を除去</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>完了したすべての項目をこの一覧から除去</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>リストをクリア</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>すべての項目をこの一覧から除去</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>再試行(&amp;R)</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>再試行</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>選択したタスクを再試行</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>すべて再試行(&amp;A)</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>すべてのタスクを再試行</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>設定(&amp;O)</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>このプログラムに関する情報</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>出力ファイル名を変更(&amp;F)</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>選択した項目の出力ファイル名を変更</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>出力先を変更(&amp;D)</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>選択した項目を出力するディレクトリを変更</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>エラーメッセージを表示(&amp;M)</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>アップデートの確認(&amp;U)</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation>切り取り</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>すべてのタスクが終了しました。</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>変換する対象がありません</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>現在変換処理中です、中断しますか?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>すべてのタスク完了後にシャットダウン</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>サスペンド</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>すべてのタスク完了後にサスペンド</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>休止状態</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>すべてのタスク完了後に休止状態</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>このプログラムでは、オンラインでアップデートの確認を行います。インターネットを使用した更新の確認を許可しますか?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>プリセットファイルの読み込みに失敗しました。プログラムを終了します。</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>経過時間:: %1 時間 %2 分 %3 秒</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation>MystiQ メディア コンバータ</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>一覧をクリア(&amp;L)</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>MistiQ について</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>電源を切る</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>ユーザ マニュアル</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>エラー報告(&amp;R)</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>エラー報告</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>寄付</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>変換に失敗しました。</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>MystiQ を支援</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ ではあなたの協力を必要としています。</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ はフリーのソフトウェアです。 しかし、開発には非常に多くの時間と作業が必要となります。 MystiQ へ新機能を追加したり、開発を今後も継続していくには、あなたの支援が必要です。&#x3000;もし MystiQ を気に入って頂けたなら、寄付によるプロジェクトの支援を是非ご検討ください。&lt;b&gt;たとえ少額であっても私たちには大きな助けとなります。&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>MystiQ からのエラー報告 </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>あなたのコメント:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Report:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation>MystiQ で変換中 %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation>MystiQ ビデオ コンバータ</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>変換が正常に完了しました。</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>翻訳する</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>アプリケーションを翻訳</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Github</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation>FFmpegまたはFFprobe ％1 がシステムで見つかりませんでした。 MystiQを実行する前にそれらをインストールすることを検討してください</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>プログラム起動時にアップデートの有無を確認する</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>一覧にファイルを追加後、自動的に変換を開始する</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>変換を自動的に開始</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>変換に使用するスレッド数</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;現在インストールされている ffmpeg では使用できない出力形式を非表示にします。 MystiQ による使用可能な形式の検出に不具合がある場合を除き、このオプションは有効にすることをお勧めします(オプションの変更には再起動が必要となります)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>使用できない形式を非表示にする (再起動が必要)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>ツール</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>変更を有効にするには、MystiQ を再起動する必要があります。</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>すぐにシャットダウンする</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>すぐにサスペンド</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>すぐに休止状態へ移行</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>サスペンド</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>休止状態</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>操作に失敗しました:%1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; 秒後にシャットダウン</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; 秒後にサスペンド</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; 秒後に休止状態</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>選択した範囲を再生</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>最初</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>最後</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation>再生 %1 ~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>ビデオプレビュー</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>先頭から</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>末尾まで</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>リリースノートを表示(&amp;R)</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>プログラム起動時にアップデートの有無を確認</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>更新情報をダウンロードしています...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>サーバに接続できません。</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>受信したデータの解析に失敗しました。</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>既に最新バージョンの MystiQ を使用しています。</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>不明なエラーが発生しました。</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>MystiQ の新バージョンがリリースされています!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>バージョン &lt;b&gt;%1&lt;/b&gt; が %2 で利用可能です。</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>このバージョンは、次のリンクからダウンロードできます:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>アップデートをチェックする</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
